Using a standard spin lock SafeLock, lock it and execute the
critical section. The critical section itself is a synchronous function or closure. In this case,
the critical section simply retrieves a value from a guarded dataset.
Using a standard spin lock SafeLock, lock it and execute the
critical section. The critical section itself is a synchronous function or closure. In this case,
the critical section attempts to modify the internal state of a guarded dataset.
First, let’s make sure we have tokio initialized at least once. The runtime created here
will be saved to the global context so the next call to this macro will simply grab a
reference to the previously initialized runtime.
Given a series of RUMCommand passed to this macro, prepare
and execute the commands in a pipeline. A pipeline here refers to the Unix style pipeline which is the
terminal form of a pipeline. The pipeline behaves like it would in the terminal => ls | wc.
Given a series of RUMCommand passed to this macro, prepare
and execute the commands in a pipeline. A pipeline here refers to the Unix style pipeline which is the
terminal form of a pipeline. The pipeline behaves like it would in the terminal => ls | wc.
This macro is similar to rumtk_pipeline_quick_run. The difference here
is that the function takes a pipeline structure (RUMCommandLine)
In other words, this macro simply runs an already defined pipeline.
This macro is similar to rumtk_pipeline_quick_run_async. The difference here
is that the function takes a pipeline structure (RUMCommandLine)
In other words, this macro simply runs an already defined pipeline.
Macro for starting the server. When a server is created, it does not start accepting clients
right away. You need to call this macro to do that or call [tcp::RUMServerHandle::start]
directly.