Module buffers

Module buffers 

Structs

RUMBuffer
A cheaply cloneable and sliceable chunk of contiguous memory.
RUMBufferMut
A unique reference to a contiguous slice of memory.
RUMBufferSplitIter
RUMSliceEnumerateIter
RUMSliceSplitIter

Constants

DEFAULT_BUFFER_CHUNK_SIZE
DEFAULT_BUFFER_ITEM_COUNT

Traits

BufMut
A trait for values that provide sequential write access to bytes.
RUMBufferIteratorExt
RUMBufferSplitIterTrait
RUMByteSliceEnumeratorIterTrait
RUMByteSliceIteratorExt
RUMByteSliceSplitIterTrait

Functions

buffer_chunk_find
buffer_count
buffer_find
buffer_find_byte
buffer_find_instances
buffer_has_pattern
buffer_pad
buffer_replace
buffer_replace_in_place
buffer_slice_trim
buffer_split_fast
buffer_to_str
buffer_to_string
Convert buffer to string.
buffer_trim
is_unique_bytes
new_random_buffer
Generates a new random buffer using the rand crate and wrapped inside a RUMBuffer.
new_random_rumbuffer
Generates a new random buffer using the rand crate and wrapped inside a RUMBuffer.
new_random_string_buffer
Generates a new random string using the rand crate and wrapped inside a RUMString.
new_random_string_set
Generates a new random set of RUMString using the rand crate.
slice_to_buffer
Convert slice of &[u8] to RUMBuffer.