Module cache

Module cache 

Modules

cache_macros

Structs

Lazy
A value which is initialized on the first access.

Constants

DEFAULT_CACHE_PAGE_SIZE
I don’t think most scenarios will need more than 10 items worth of memory pre-allocated at a time.

Functions

cache_get⚠
cache_get_or_set⚠
cache_push⚠
new_cache

Type Aliases

LazyRUMCache
LockedCache
RUMCache
Generic Cache store object. One use case will be to use a search string as the key and store the search parsing object here.
RUMCacheMutValue
RUMCacheValue
RUMCacheWriteGuard