Module core

Module core 

Constants

DEFAULT_BUFFER_CHUNK_SIZE
DEFAULT_BUFFER_ITEM_COUNT

Functions

clamp_index
Take a requested index and the maximum size of the item container. Check if the index is valid and return an error if it is. The purpose of this function is to enable handling of out of bounds without triggering a panic. Also, add negative indices like Python does when doing a reverse search!
is_unique
new_random_buffer
Generates a new random buffer using the rand crate and wrapped inside a RUMBuffer.
new_random_rumbuffer
Generates a new random buffer using the rand crate and wrapped inside a RUMBuffer.
new_random_string_buffer
Generates a new random string using the rand crate and wrapped inside a RUMString.
new_random_string_set
Generates a new random set of RUMString using the rand crate.
slice_to_buffer
Convert slice of &[u8] to RUMBuffer.

Type Aliases

RUMError
RUMResult
Type used for propagating error messages.
RUMVec