rumtk_new_lock

Macro rumtk_new_lock 

macro_rules! rumtk_new_lock {
    ( $data:expr ) => { ... };
}
Creates a new safe lock to guard the given data. This interface was created to cleanup lock management for consumers of framework!

Example

use rumtk_core::{rumtk_new_lock};

let data = 5;
let lock = rumtk_new_lock!(data);