rumtk_write_stdout

Macro rumtk_write_stdout 

macro_rules! rumtk_write_stdout {
    ( $message:expr ) => { ... };
    ( $message:expr, $binary:expr ) => { ... };
}
Writes RUMString or RUMBuffer to stdout.

If the binary parameter is passed, we push the message parameter directly to stdout. the message parameter has to be of type RUMBuffer.

Example

Default / Pushing a String

use rumtk_core::rumtk_write_stdout;

rumtk_write_stdout!("I ❤ my wife!");

Pushing Binary Buffer

use rumtk_core::rumtk_write_stdout;
use rumtk_core::core::new_random_buffer;

let buffer = new_random_buffer();
rumtk_write_stdout!(buffer, true);