Traits
- RUMDe
Json - A data structure that can be deserialized from any data format supported by Serde.
- RUMJson
Deserializer - A data format that can deserialize any data structure supported by Serde.
- RUMJson
Serializer - A data format that can serialize any data structure supported by Serde.
- RUMSer
Json - A data structure that can be serialized into any data format supported by Serde.