GraphemeStr

Struct GraphemeStr 

pub struct GraphemeStr<'a> { /* private fields */ }
The equivalent to a stringview but at the grapheme level. Meaning, we can use this view to iterate through a string at the full UTF8 implementation

Implementations

Source

impl<'a> GraphemeStr<'a>

pub fn from(string: &'a str) -> Self

pub fn from_view(view: GraphemeStringView<'a>) -> Self

pub fn at(&self, index: usize) -> Grapheme<'a>

pub fn trim(&self, pattern: &GraphemePatternPair<'a>) -> Self

pub fn trim_left(&self, pattern: &GraphemePattern<'a>) -> Self

pub fn trim_right(&self, pattern: &GraphemePattern<'a>) -> Self

pub fn splice(&self, skip_pattern: &GraphemePatternPair<'a>) -> Self

pub fn find(&self, pattern: &GraphemePattern<'a>, offset: usize) -> usize

pub fn rfind(&self, pattern: &GraphemePattern<'a>, offset: usize) -> usize

pub fn len(&self) -> usize

pub fn get_graphemes(&self) -> GraphemeSlice<'_, 'a>

pub fn truncate(&self, size: usize) -> Self

pub fn is_unique(&self) -> bool