Module buffers

Module buffers 

Modules

constants
helpers
rumbuffer
serde_impl
types

Structs

RUMBuffer
The RUMBuffer type is meant to be a very lightweight owned buffer pointer. The impetus for building this type is that benchmarking showed a potential vector getting allocated by the bytes crate. I was using the bytes crate before because it is a very solid crate. However, the vector allocations worried me. It was likely part of that crates interior mutability strategy with vtables but it was one of a few areas consuming a lot of time and most importantly consuming kernel time by invoking malloc.
RUMBufferSplitIter
RUMSliceEnumerateIter
RUMSliceSplitIter

Constants

DEFAULT_BUFFER_CHUNK_SIZE
DEFAULT_BUFFER_ITEM_COUNT
DEFAULT_BYTE_WINDOW_SIZE

Traits

RUMBufferIteratorExt
RUMBufferSplitIterTrait
RUMByteSliceEnumeratorIterTrait
RUMByteSliceIteratorExt
RUMByteSliceSplitIterTrait

Functions

buffer_contains
buffer_count
buffer_find
buffer_find_byte
buffer_find_instances
buffer_has_pattern
buffer_replace
buffer_replace_in_place
buffer_slice_trim
buffer_to_str
buffer_to_string
Convert buffer to string.
buffer_trim
is_unique_bytes
new_random_buffer
Generates a new random buffer using the rand crate and wrapped inside a RUMBuffer.
new_random_rumbuffer
Generates a new random buffer using the rand crate and wrapped inside a RUMBuffer.
new_random_string_buffer
Generates a new random string using the rand crate and wrapped inside a RUMString.
new_random_string_set
Generates a new random set of RUMString using the rand crate.
slice_to_buffer
Convert slice of &[u8] to RUMBuffer.