Modules
Structs
- RUMBuffer
- The RUMBuffer type is meant to be a very lightweight owned buffer pointer. The impetus for building this type is that benchmarking showed a potential vector getting allocated by the bytes crate. I was using the bytes crate before because it is a very solid crate. However, the vector allocations worried me. It was likely part of that crates interior mutability strategy with vtables but it was one of a few areas consuming a lot of time and most importantly consuming kernel time by invoking malloc.
- RUMBuffer
Split Iter - RUMSlice
Enumerate Iter - RUMSlice
Split Iter
Constants
Traits
- RUMBuffer
Iterator Ext - RUMBuffer
Split Iter Trait - RUMByte
Slice Enumerator Iter Trait - RUMByte
Slice Iterator Ext - RUMByte
Slice Split Iter Trait
Functions
- buffer_
contains - buffer_
count - buffer_
find - buffer_
find_ byte - buffer_
find_ instances - buffer_
has_ pattern - buffer_
replace - buffer_
replace_ in_ place - buffer_
slice_ trim - buffer_
to_ str - buffer_
to_ string - Convert buffer to string.
- buffer_
trim - is_
unique_ bytes - new_
random_ buffer - Generates a new random buffer using the
randcrate and wrapped inside a RUMBuffer. - new_
random_ rumbuffer - Generates a new random buffer using the
randcrate and wrapped inside a RUMBuffer. - new_
random_ string_ buffer - Generates a new random string using the
randcrate and wrapped inside a RUMString. - new_
random_ string_ set - Generates a new random set of RUMString using the
randcrate. - slice_
to_ buffer - Convert slice of
&[u8]to RUMBuffer.