Constants
Functions
- clamp_
index - Take a requested index and the maximum size of the item container. Check if the index is valid and return an error if it is. The purpose of this function is to enable handling of out of bounds without triggering a panic. Also, add negative indices like Python does when doing a reverse search!
- is_
unique - new_
random_ buffer - Generates a new random buffer using the
randcrate and wrapped inside a RUMBuffer. - new_
random_ rumbuffer - Generates a new random buffer using the
randcrate and wrapped inside a RUMBuffer. - new_
random_ string_ buffer - Generates a new random string using the
randcrate and wrapped inside a RUMString. - new_
random_ string_ set - Generates a new random set of RUMString using the
randcrate. - slice_
to_ buffer - Convert slice of
&[u8]to RUMBuffer.