macro_rules! rumtk_resolve_sync_task {
( $closure:expr ) => { ... };
}Expand description
This macro allows to resolve a sync closure that was executed in a safe thread.
You cannot run this macro outside the async context.
macro_rules! rumtk_resolve_sync_task {
( $closure:expr ) => { ... };
}This macro allows to resolve a sync closure that was executed in a safe thread.
You cannot run this macro outside the async context.