Module json

Module json 

Traits

RUMDeJson
A data structure that can be deserialized from any data format supported by Serde.
RUMDeJsonError
The Error trait allows Deserialize implementations to create descriptive error messages belonging to the Deserializer against which they are currently running.
RUMDeJsonVisitor
This trait represents a visitor that walks through a deserializer.
RUMJsonDeserializer
A data format that can deserialize any data structure supported by Serde.
RUMJsonSerializer
A data format that can serialize any data structure supported by Serde.
RUMSerJson
A data structure that can be serialized into any data format supported by Serde.
RUMSerJsonError
Trait used by Serialize implementations to generically construct errors belonging to the Serializer against which they are currently running.
RUMSerJsonSerializeMap
Returned from Serializer::serialize_map.
RUMSerJsonSerializeSequence
Returned from Serializer::serialize_seq.
RUMSerJsonSerializeStruct
Returned from Serializer::serialize_struct.

Functions

from_json
to_json

Derive Macros

RUMDeJson
RUMSerJson