Traits
- RUMDe
Json - A data structure that can be deserialized from any data format supported by Serde.
- RUMDe
Json Error - The
Errortrait allowsDeserializeimplementations to create descriptive error messages belonging to theDeserializeragainst which they are currently running. - RUMDe
Json Visitor - This trait represents a visitor that walks through a deserializer.
- RUMJson
Deserializer - A data format that can deserialize any data structure supported by Serde.
- RUMJson
Serializer - A data format that can serialize any data structure supported by Serde.
- RUMSer
Json - A data structure that can be serialized into any data format supported by Serde.
- RUMSer
Json Error - Trait used by
Serializeimplementations to generically construct errors belonging to theSerializeragainst which they are currently running. - RUMSer
Json Serialize Map - Returned from
Serializer::serialize_map. - RUMSer
Json Serialize Sequence - Returned from
Serializer::serialize_seq. - RUMSer
Json Serialize Struct - Returned from
Serializer::serialize_struct.