Module json

Module json 

Traits

RUMDeJson
A data structure that can be deserialized from any data format supported by Serde.
RUMJsonDeserializer
A data format that can deserialize any data structure supported by Serde.
RUMJsonSerializer
A data format that can serialize any data structure supported by Serde.
RUMSerJson
A data structure that can be serialized into any data format supported by Serde.

Functions

from_json
to_json

Derive Macros

RUMDeJson
RUMSerJson