This module contains a few helper.
For example, you can find a function for determining number of threads available in system. The sleep family of functions are also here.
Constants
Functions
- async_
sleep - block_
on_ task - Given a closure task, push it onto the current
tokioruntime for execution. Every [DEFAULT_SLEEP_DURATION] seconds, we check if the task has concluded. Once the task has concluded, we call tokio::block_on to resolve and extract the task result. - get_
default_ system_ thread_ count - init_
runtime - lock_
read - Obtain read guard to standard spin lock such that you have a more ergonomic interface to locked data.
- lock_
write - Obtain write guard to standard spin lock such that you have a more ergonomic interface to locked data.
- new_
lock - process_
read_ critical_ section - This function gives you read access to underlying structure.
- process_
write_ critical_ section - This function gives you write access to underlying structure.
- sleep
- spawn_
blocking_ sync_ task - This helper should be used for spawning tasks that would normally block the async runtime.
However, here we use the appropriate
tokiofacilities to signal the runtime on how to handle this, potentially blocking, task. For waiting on potentially blocking futures, use block_on_task instead!