This module contains a few helper.
For example, you can find a function for determining number of threads available in system. The sleep family of functions are also here.
Re-exports
pub use crate::threading::thread_primitives::init_runtime;
Constants
Functions
- async_
sleep - block_
on_ task - Given a closure task, push it onto the current
tokioruntime for execution. Every [DEFAULT_SLEEP_DURATION] seconds, we check if the task has concluded. Once the task has concluded, we call tokio::block_on to resolve and extract the task result. - get_
default_ system_ thread_ count - sleep